##  Editing Import Rules
  1. In the administration area of SAP LeanIX, go to Integrations > Atlassian Jira and select the integration instance.
  2. On the Import Rules tab, choose the rule you want to modify.
  3. Update the rule settings, such as Jira project, issue type, labels, or parent initiative.
  4. Choose Save to apply changes.
